from xmlrpclib import ServerProxy

from trainingwebsite.certification.utils import datetime_to_string


class AccessBase(object):

    def __init__(self, server):
        self.server = server

    def _call(self, func_name, *args):
        parsed_args = ["System"]
        for arg in args:
            arg = datetime_to_string(arg)
            parsed_args.append(arg)

        func = getattr(self.server, func_name)
        return func(*parsed_args)

    def get_all(self):
        raise NotImplementedError

    def get_deleted(self, start_datetime, end_datetime):
        raise NotImplementedError

    def get_updated(self, start_datetime, end_datetime):
        raise NotImplementedError


class AccessServer(ServerProxy):

    def get_timestamp(self):
        return self.getServerTimestamp()


class AccountAccess(AccessBase):

    def get_all(self):
        return self._call("getAllAccounts")

    def get_deleted(self, start_datetime, end_datetime):
        return self._call("getDeletedAccounts", start_datetime, end_datetime)

    def get_updated(self, start_datetime, end_datetime):
        return self._call("getUpdatedAccounts", start_datetime, end_datetime)


class HardwareAccess(AccessBase):

    def get_all(self):
        return self._call("getAllHardware")

    def get_deleted(self, start_datetime, end_datetime):
        return self._call("getDeletedHardware", start_datetime, end_datetime)

    def get_updated(self, start_datetime, end_datetime):
        return self._call("getUpdatedHardware", start_datetime, end_datetime)


class CertificateAccess(AccessBase):

    def get_all(self):
        return self._call("getAllCertificates")

    def get_deleted(self, start_datetime, end_datetime):
        return self._call("getDeletedCertificates", start_datetime, end_datetime)

    def get_updated(self, start_datetime, end_datetime):
        return self._call("getUpdatedCertificates", start_datetime, end_datetime)


class CertificateNoteAccess(AccessBase):

    def get_all(self):
        return self._call("getAllCertificateNotes")

    def get_deleted(self, start_datetime, end_datetime):
        return self._call("getDeletedCertificateNotes", start_datetime, end_datetime)

    def get_updated(self, start_datetime, end_datetime):
        return self._call("getUpdatedCertificateNotes", start_datetime, end_datetime)
