from django.db.models import (Model, CharField, DateTimeField, IntegerField,
    TextField, ForeignKey)

from trainingwebsite.certification.managers import EntryManager


certification_map = {
    "Certification": "Certified",
    "Compatibility": "Compatible"}


class ModelBase(object):

    def update(self, **kwargs):
        for k, v in kwargs.items():
            setattr(self, k, v)
        self.save()


class Cache(Model):
    id = CharField(maxlength=15, unique=True, primary_key=True)
    last_updated = DateTimeField("last updated", null=True)


class Account(ModelBase, Model):
    id = CharField(maxlength=19, unique=True, primary_key=True)
    name = CharField(maxlength=255)
    website = CharField(maxlength=80)

    @property
    def hardware(self):
        return Hardware.objects.filter(account=self.id)

    def create_hardware(self, **kwargs):
        kwargs["account"] = self
        return Hardware.objects.create(**kwargs)


class Hardware(ModelBase, Model):
    id = CharField(maxlength=19, unique=True, primary_key=True)
    account = ForeignKey(Account)
    name = CharField(maxlength=12)
    make = CharField(maxlength=255)
    models = TextField(maxlength=1024, null=True)
    architecture = CharField(maxlength=5)
    category = CharField(maxlength=20)
    website = CharField(maxlength=255, null=True)
    certification = CharField(maxlength=255, null=True)
    comment = TextField(null=True)

    @property
    def model(self):
        return self.models.split("\n")[0]

    @property
    def status(self):
        return certification_map[self.certification]

    @property
    def certificates(self):
        return Certificate.objects.filter(hardware=self.id)

    def create_certificate(self, **kwargs):
        kwargs["hardware"] = self
        return Certificate.objects.create(**kwargs)


class Certificate(ModelBase, Model):
    id = CharField(maxlength=19, unique=True, primary_key=True)
    name = CharField(maxlength=80)
    reason = CharField(maxlength=80, null=True)
    completed = DateTimeField("date completed")
    release = CharField(maxlength=12)
    hardware = ForeignKey(Hardware)
    bugs = TextField(maxlength=255, null=True)

    @property
    def notes(self):
        return CertificateNote.objects.filter(certificate=self.id)


class CertificateNote(ModelBase, Model):
    id = CharField(maxlength=19, unique=True, primary_key=True)
    certificate = ForeignKey(Certificate)
    title = CharField(maxlength=80)
    body = TextField(null=True)


class Entry(ModelBase, Model):
    account_id = CharField(maxlength=19, primary_key=True, unique=False)
    account_name = CharField(maxlength=255)
    account_website = CharField(maxlength=80)
    make = CharField(maxlength=255)
    models = TextField(maxlength=1024)
    architecture = CharField(maxlength=5)
    category = CharField(maxlength=20)
    hardware_name = CharField(maxlength=12)
    hardware_website = CharField(maxlength=255)
    certification = CharField(maxlength=255)
    release = CharField(maxlength=8)
    completed = DateTimeField()
    notes = IntegerField()

    objects = EntryManager()

    @property
    def model(self):
        return self.models.split("\n")[0]

    @property
    def status(self):
        return certification_map[self.certification]

    def save(self):
        raise Exception, "Cannot save entry"
