from datetime import datetime

import unittest

from certification.models import Account, Hardware, Certificate, Entry


class EntryTestCase(unittest.TestCase):

    def setUp(self):
        account = Account.objects.create(id="id",
            name="name", website="website")

        self.hardware_a = account.create_hardware(id="ida",
            name="ida", make="makea", models="namea",
            architecture="archa", category="cata")
        self.hardware_a.create_certificate(id="ida",
            name="name", completed=datetime.now(), release="ra")

        self.hardware_b = account.create_hardware(id="idb",
            name="idb", make="makeb", models="nameb",
            architecture="archb", category="catb")
        self.hardware_b.create_certificate(id="idb",
            name="nameb", completed=datetime.now(), release="rb")

    def tearDown(self):
        Certificate.objects.all().delete()
        Hardware.objects.all().delete()
        Account.objects.all().delete()

    def _testExact(self, no, exact, case):
        # No match
        result = Entry.objects.complex_filter(search=no)
        self.assertEquals(len(result), 0)

        # Exact match
        result = Entry.objects.complex_filter(search=exact)
        self.assertEquals(len(result), 1)
        self.assertEquals(result[0].hardware_name, "ida")

        # Case insensitive match
        result = Entry.objects.complex_filter(search=case)
        self.assertEquals(len(result), 1)
        self.assertEquals(result[0].hardware_name, "ida")

    def _testContains(self, partial, multi):
        # Partial match
        result = Entry.objects.complex_filter(search=partial)
        self.assertEquals(len(result), 1)
        self.assertEquals(result[0].hardware_name, "ida")

        # Multi match
        result = Entry.objects.complex_filter(search=multi)
        self.assertEquals(len(result), 1)
        self.assertEquals(result[0].hardware_name, "ida")

    def testMake(self):
        self._testExact("makec", "makea", "MaKeA")
        self._testContains("akea", "make akea")

    def testModel(self):
        self._testExact("namec", "namea", "NaMeA")
        self._testContains("amea", "name amea")

    def testArchitecture(self):
        self._testExact("archc", "archa", "ArChA")

    def testCategory(self):
        self._testExact("catc", "cata", "CaTa")
