from django.http import Http404, HttpResponseRedirect, HttpResponse
from django.shortcuts import render_to_response, get_object_or_404
from trainingwebsite.course_locator.models import *
from datetime import datetime, timedelta

# Create your views here.
def country_list(request):
    start = datetime.now()
    end = endofmonth(3)
    countries = TrainingEvent.objects.values('Country').filter(Event_Start__range=(start,end)).distinct()
    country_list = []
    for country in countries:
        country_list.append(Country.objects.filter(Abbreviation=country['Country'])[0])
    
    mapping = {'country_list': country_list}
    return render_to_response('course_locator/views/country_list.html', mapping)

def course_list(request, country):
    start = datetime.now()
    end = endofmonth(2)
    country_details = Country.objects.filter(Abbreviation=country)[0]
    course_list = TrainingEvent.objects.filter(Country__exact=country).filter(Event_Start__range=(start,end)).order_by('City','Course_Title','Event_Start')
    current_month = datetime.now().month -1
    months = []
    for i in range(current_month, current_month+3):
        if i > 11:
            months.append(MONTH_LIST[i-12])
        else:
            months.append(MONTH_LIST[i])
    
    mapping = {'course_list': course_list, 'country': country_details, 'months': months}
    return render_to_response('course_locator/views/course_list.html', mapping)

def index(request):
    return HttpResponseRedirect('/course_locator/')

def endofmonth(months = 0):
    """Return a datetime object for the last day of the month [months] from now
    
    Keyword arguments
    months -- how many months in the future (or past for -months)
    
    Note: for past dates, this is only accurate going back to the beginning of
    the previous year
    
    returns datetime
    """
    delta = timedelta(1)
    year = datetime.now().year
    month = datetime.now().month + months + 1
    day = 1
    if(month > 12):
        year += month/12
        month -= (month/12)*12
    elif(month < 1):
        # there's a logic error here, this is only good months going back to
        # one month before the first month of last year :-) so is this is 2007,
        # good for months going back to Jan 2006 - 1 month = Dec 2005
        year -= month / -12 + 1
        month += (month / -12 +1) + 11
    return datetime(year, month, day) - delta
