from django.db import models
from datetime import datetime

# Create your models here.
class Form(models.Model):
    form_name = models.CharField(maxlength = 30)
    email_address = models.CharField(maxlength = 255)
    email_subject = models.CharField(maxlength = 70)
    template = models.TextField(help_text = "Please paste the e-mail template you wish to use. E-mails should contain text only.")
    redirect_url = models.CharField(maxlength = 70)
    error_message = models.TextField(help_text = "give the error message that should be shown if there is an error (i.e. a required field isn't completed)")
    created_date = models.DateField(default = datetime.now())
    
    class Admin:
        list_display = ('form_name', 'email_address', 'created_date')
        list_filter = ['created_date', 'email_address']
        date_hierarchy = 'created_date'
    
    def __str__(self):
        return self.form_name

class FieldType(models.Model):
    field_type = models.CharField(maxlength = 70)
    
    class Admin:
        pass
    
    def __str__(self):
        return self.field_type

class RequiredFields(models.Model):
    form = models.ForeignKey(Form, edit_inline=models.TABULAR, num_in_admin=3)
    field_name = models.CharField(maxlength = 70, help_text = """This is the "name" attribute in your form field. For example, &lt;input type=&quot;text&quot; name=&quot;email_address&quot; value=&quot;&quot;&gt; in this case, you'd enter email_address here.""")
    friendly_name = models.CharField(maxlength = 70, core=True)
    field_type = models.ForeignKey(FieldType)
    error_message = models.CharField(maxlength = 70)
    
    def __str__(self):
        return self.field_name    