# Create your views here.
from django.http import Http404, HttpResponse, HttpResponseRedirect
from django.shortcuts import render_to_response, get_object_or_404
from django.template import Context, Template
from trainingwebsite.formmail.models import Form, FieldType, RequiredFields
from django.core.mail import send_mail

def submit(request, form_id):
    # get the form details
    form_details = get_object_or_404(Form, pk=form_id)
    
    errors = {}
    # check that we have all the required fields
    for requiredfield in form_details.requiredfields_set.all():
        fieldtype = requiredfield.field_type.field_type
        try:
            if fieldtype == 'text':
                # validate for text only
                if request.REQUEST[requiredfield.field_name] == '':
                    errors[requiredfield.field_name] = {'name':requiredfield.friendly_name,
                                                        'message': requiredfield.error_message}
            
            elif fieldtype == 'number':
                if request.REQUEST[requiredfield.field_name] == '':
                    errors[requiredfield.field_name] = {'name':requiredfield.friendly_name,
                                                        'message': requiredfield.error_message}
                pass
            
            else:
                # validate for non-null type
                if request.REQUEST[requiredfield.field_name] == '':
                    errors[requiredfield.field_name] = {'name':requiredfield.friendly_name,
                                                        'message': requiredfield.error_message}
        except (KeyError):
            errors[requiredfield.field_name] = {'name':requiredfield.friendly_name,
                                                'message': requiredfield.error_message}
    
    # stop if there are errors
    if errors:
        try:
            referrer = request.META['HTTP_REFERER']
        except (KeyError):
            referrer = ''
        
        return render_to_response('formmail/views/form_error.html', {'errors': errors, 'referrer': referrer})
    
    # grab the e-mail template from the database and populate it with the post
    template = Template(form_details.template)
    fields = []
    
    for key,value in request.POST.iteritems():
        fields.append({'key': key, 'value': value})
    
    vars = Context({'fields': fields})
    message = template.render(vars)

    # send the e-mail
    subject = form_details.email_subject.split('\n')[0]
    send_mail(subject, message, form_details.email_address, [form_details.email_address])
    
    # redirect to the specified page
    return HttpResponseRedirect(form_details.redirect_url)
