from django.db import models
from datetime import datetime
import time
import csv
from BeautifulSoup import BeautifulSoup

# Create your models here.

class Partner(models.Model):
    region = models.CharField(maxlength = 20)
    subregion = models.CharField(maxlength = 50)
    country = models.CharField(maxlength = 50)
    start_date = models.DateField()
    expires_date = models.DateField()
    name = models.CharField(maxlength = 100)
    website = models.URLField(verify_exists = False)
    description = models.TextField()
    
    def __str__(self):
        return "%s (%s)" % (self.name, self.country)
    
    class Admin:
        list_display = ('name','region', 'country')
        list_filter = ['region']

class Upload(models.Model):
    upload_file = models.FileField(upload_to = 'marketplace_csv/', blank = True, 
                                   help_text = """To update the data, use this field 
                                   to upload a CSV formatted spreadsheet that has the 
                                   following columns (in this order): Marketplace Region, 
                                   Marketplace Sub-Region, Billing Country, Install Date, 
                                   Usage End Date, Account Name, Website, Marketplace Text""")
    upload_data = models.TextField(help_text = "Don't edit this data", blank = True)
    created_date = models.DateTimeField(auto_now_add = True, help_text = "Don't edit this data")
    deprecated_date = models.DateTimeField(null = True, blank = True, help_text = "Don't edit this data")
    
    class Admin:
        #pass
        fields = (
                (None, {'fields': ('upload_file',)}),
                ('Hidden Fields', {'fields':('upload_data','deprecated_date'), 'classes': 'collapse'}),
                  )
    
    def save(self, norecurse = False):
        if norecurse != False:
            super(Upload, self).save()

        #read the data from the file, save as upload_data
        fd = open(self.get_upload_file_filename())
        self.upload_data = str(BeautifulSoup(fd.read()))
        fd.close()
        
        # mark past entries with empty deprecated_date to now to archive them
        old = Upload.objects.filter(deprecated_date__isnull = True)
        count = 0
        for item in old:
            count = count + 1
            item.deprecated_date = datetime.now()
            item.save(norecurse = True)
            
        # delete all the Partners and then re add them from the spreadsheet
        Partner.objects.all().delete()
        
        # get rid of the first line, it contains a header row
        data = self.upload_data.splitlines()
        data = data[1:]
        
        # now add each line to the database
        lines = csv.reader(data, quotechar='"', quoting=csv.QUOTE_NONE)
        for line in lines:
            # Remove "s from lines.
            #line = line.strip('"')
            # skip blank or incomplete lines
            if 8 <= len(line) and line[0] != '':
                #ugly date conversion
                startdate = datetime.fromtimestamp(
                    time.mktime(time.strptime(line[3], '%d/%m/%Y')))
                expiresdate = datetime.fromtimestamp(
                    time.mktime(time.strptime(line[4], '%d/%m/%Y')))
                p = Partner(region = line[0],
                            subregion = line[1],
                            country = line[2],
                            start_date = startdate,
                            expires_date = expiresdate,
                            name = line[5],
                            website = line[6],
                            description = ' '.join(line[7:]))
                p.save()
                
        # save the record
        super(Upload, self).save()
    
