from django.db import connection, backend, models
from datetime import datetime
from django.core.exceptions import ObjectDoesNotExist
from trainingwebsite.course_locator.models import Country

# Create your models here.
CONTINENT_LIST = (
    ("AS", "Asia"),
    ("AF", "Africa"),
    ("EU", "Europe"),
    ("ME", "Middle East"),
    ("NA", "North America"),
    ("OC", "Oceania/Australia"),
    ("SA", "South America/Latin America"),
    )

PARTNER_LEVELS = (
    ("gold", "Gold"),
    ("silv", "Silver"),
    ("stan", "Standard"),
    )

class Type(models.Model):
    type = models.CharField(maxlength = 30)
    abbreviation = models.CharField(maxlength = 8, help_text = "This is a short version of the partner type but using no more than 8 letters or numbers (no punctuation or spaces)")
    
    def __str__(self):
        return self.type
    
    class Admin:
        pass

class Service(models.Model):
    service = models.CharField(maxlength = 30)
    abbreviation = models.CharField(maxlength = 30, help_text = "This is a short version of the service name but with no punctuation or spaces")
    #objects = ServiceManager()

    
    def __str__(self):
        return self.service
    
    class Admin:
        pass

class Partner(models.Model):
    continent = models.CharField(maxlength = 2, choices = CONTINENT_LIST)
    country = models.ForeignKey(Country)
    name = models.CharField(maxlength = 70)
    website = models.URLField(verify_exists = False, help_text = "Ensure that the web address begins with http://")
    description = models.TextField(help_text = "Write a paragraph to describe this partner containing only text, no html")
    logo = models.ImageField(upload_to = 'partner_logos/', help_text = "Logos should be images in png, gif or jpg format and should be no wider than 180px and no taller than 180px")
    created_date = models.DateField(help_text = "you can delay entry into the partner page by setting this date in the future")
    expires_date = models.DateField(help_text = "Enter a date here indicating when this partner should be automatically delisted")
    partner_level = models.CharField(maxlength = 4, choices = PARTNER_LEVELS)
    partner_type = models.ManyToManyField(Type, filter_interface = models.HORIZONTAL)
    services = models.ManyToManyField(Service, blank = True, filter_interface = models.HORIZONTAL, help_text = "Choose a one or more services this partner provides. You can add additional services to the list by clicking the plus sign, but keep this list short and ensure the service list is well thought out.")
    
    def __str__(self):
        return "%s (%s)" % (self.name, self.country)
    
    class Admin:
         list_display = ('name', 'partner_level', 'continent', 'country',)
         list_filter = ('continent', 'partner_level', 'partner_type',)
         search_fields = ('title',)
    

def ServiceList():
    from django.db import connection
    cursor = connection.cursor()
    query = """
    select 
        service, abbreviation, count(*) 
    from 
        partners_service 
        inner join partners_partner_services on 
            partners_service.id = service_id 
    group by 
        service, abbreviation;"""
    cursor.execute(query)
    return cursor.fetchall()