# Create your views here.
from django.http import Http404, HttpResponse, HttpResponseRedirect
from django.shortcuts import render_to_response, get_object_or_404
from django.template import Context, Template, RequestContext
from django.db.models import Q
from trainingwebsite.partners.models import *
from datetime import datetime

def partner_list(request, type = '', service = ''):
    now = datetime.now()
    partners = Partner.objects.all()
    base_filters = Q(created_date__lte = now) & Q(expires_date__gt = now)
    if type != '':
        filters =  base_filters & Q(partner_type__abbreviation__exact = type)
    
    if service != '':
        filters =  base_filters & Q(services__abbreviation__exact = service)
    
    
    #AF = {'abbrv': 'af', 'name': 'Africa', 'results': Partner.objects.filter(continent__exact = 'AF').filter(created_date__lte = now).filter(expires_date__gt = now).order_by('country','partner_level','name')}
    AF = {'abbrv': 'af', 'name': 'Africa', 'results': partners.filter(filters & Q(continent__exact = 'AF')).order_by('course_locator_country.Country','partner_level','name').select_related()}
    #AS = {'abbrv': 'as', 'name': 'Asia', 'results': Partner.objects.filter(continent__exact = 'AS').filter(created_date__lte = now).filter(expires_date__gt = now).order_by('country','partner_level','name')}
    AS = {'abbrv': 'as', 'name': 'Asia', 'results': partners.filter(filters & Q(continent__exact = 'AS')).order_by('course_locator_country.Country','partner_level','name').select_related()}
    #EU = {'abbrv': 'eu', 'name': 'Europe', 'results': Partner.objects.filter(continent__exact = 'EU').filter(created_date__lte = now).filter(expires_date__gt = now).order_by('country','partner_level','name')}
    EU = {'abbrv': 'eu', 'name': 'Europe', 'results': partners.filter(filters & Q(continent__exact = 'EU')).order_by('course_locator_country.Country','partner_level','name').select_related()}
    #ME = {'abbrv': 'me', 'name': 'Middle East', 'results': Partner.objects.filter(continent__exact = 'ME').filter(created_date__lte = now).filter(expires_date__gt = now).order_by('country','partner_level','name')}
    ME = {'abbrv': 'me', 'name': 'Middle East', 'results': partners.filter(filters & Q(continent__exact = 'ME')).order_by('course_locator_country.Country','partner_level','name').select_related()}
    #NA = {'abbrv': 'na', 'name': 'North America', 'results': Partner.objects.filter(continent__exact = 'NA').filter(created_date__lte = now).filter(expires_date__gt = now).order_by('country','partner_level','name')}
    NA = {'abbrv': 'na', 'name': 'North America', 'results': partners.filter(filters & Q(continent__exact = 'NA')).order_by('course_locator_country.Country','partner_level','name').select_related()}
    #OC = {'abbrv': 'oc', 'name': 'Oceania and Australia', 'results': Partner.objects.filter(continent__exact = 'OC').filter(created_date__lte = now).filter(expires_date__gt = now).order_by('country','partner_level','name')}
    OC = {'abbrv': 'oc', 'name': 'Oceania and Australia', 'results': partners.filter(filters & Q(continent__exact = 'OC')).order_by('course_locator_country.Country','partner_level','name').select_related()}
    #SA = {'abbrv': 'sa', 'name': 'South America', 'results': Partner.objects.filter(continent__exact = 'SA').filter(created_date__lte = now).filter(expires_date__gt = now).order_by('country','partner_level','name')}
    SA = {'abbrv': 'sa', 'name': 'South America', 'results': partners.filter(filters & Q(continent__exact = 'SA')).order_by('course_locator_country.Country','partner_level','name').select_related()}
    
    mapping = {'continents':(AF,AS,EU,ME,NA,OC,SA), 'type': type, 'service': service}
    return render_to_response('partners/views/country_list.html', mapping, context_instance=RequestContext(request))

def software_list(request, type = '', service = ''):
    now = datetime.now()
    partners = Partner.objects.all()
    base_filters = Q(created_date__lte = now) & Q(expires_date__gt = now)
    if type != '':
        filters =  base_filters & Q(partner_type__abbreviation__exact = type)
    
    if service != '':
        filters =  base_filters & Q(services__abbreviation__exact = service)
    
    
    #AF = {'abbrv': 'af', 'name': 'Africa', 'results': Partner.objects.filter(continent__exact = 'AF').filter(created_date__lte = now).filter(expires_date__gt = now).order_by('country','partner_level','name')}
    GOLD = {'abbrv': 'gold', 'name': 'Gold Partners', 'results': partners.filter(filters & Q(partner_level__exact = 'gold')).order_by('name')}
    #AS = {'abbrv': 'as', 'name': 'Asia', 'results': Partner.objects.filter(continent__exact = 'AS').filter(created_date__lte = now).filter(expires_date__gt = now).order_by('country','partner_level','name')}
    SILVER = {'abbrv': 'silver', 'name': 'Silver Partners', 'results': partners.filter(filters & Q(partner_level__exact = 'silv')).order_by('name')}
    #EU = {'abbrv': 'eu', 'name': 'Europe', 'results': Partner.objects.filter(continent__exact = 'EU').filter(created_date__lte = now).filter(expires_date__gt = now).order_by('country','partner_level','name')}
    OTHER = {'abbrv': 'other', 'name': 'Partners', 'results': partners.filter(filters & Q(partner_level__exact = 'stan')).order_by('name')}
    
    mapping = {'categories':(GOLD, SILVER, OTHER)}
    return render_to_response('partners/views/software_list.html', mapping, context_instance=RequestContext(request))

def cloud_list(request, type = '', service = ''):
    now = datetime.now()
    partners = Partner.objects.all()
    base_filters = Q(created_date__lte = now) & Q(expires_date__gt = now)
    if type != '':
        filters =  base_filters & Q(partner_type__abbreviation__exact = type)
    
    cloud_partners = {'results': partners.filter(filters).order_by('name')}
    
    mapping = {'cloud_partners': cloud_partners}
    return render_to_response('partners/views/cloud.html', mapping, context_instance=RequestContext(request))

def index(request):
    mapping = {'services': ServiceList()}
    return render_to_response('partners/views/index.html', mapping, context_instance=RequestContext(request))
